@@ -17,11 +17,11 @@ RDF::KV::Patch - Representation of RDF statements to be added or removed
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -348,7 +348,7 @@ sub graphs_affected {
     map { _node($_) } keys %seen;
 }
 
-=head2 subjects_affected
+=head2 subjects_affected [$use_graphs]
 
 Return the set of subjects that are affected by the patch,
 irrespective of graph.
@@ -356,14 +356,21 @@ irrespective of graph.
 =cut
 
 sub subjects_affected {
-    my $self = shift;
+    my ($self, $use_graphs) = @_;
     my %seen;
 
-    map {
-        $seen{$_->subject->value} = $_->subject
-    } ($self->to_add, $self->to_remove);
+    for my $stmt ($self->to_add, $self->to_remove) {
+        my $x = $seen{$stmt->graph // ''} ||= {};
+        $x->{$stmt->subject->value} = $stmt->subject;
+    }
 
-    values %seen;
+    unless ($use_graphs) {
+        my %out = map {
+            map { $_->value => $_ } values %{$seen{$_}} } keys %seen;
+        return values %out;
+    }
+
+    map { [$_, [values %{$seen{$_}} ] ] } keys %seen;
 }
 
 =head2 to_add
